<!---
Please read this!

Before opening a new issue, make sure to skim through the documentation
at http://ml.pages.km3net.de/OrcaSong
--->

### Summary

(Summarise the feature and try to provide a usage example.)

### What is the current workaround to achieve the same functionality?

(Is there already a way to get the job done?)

/label ~enhancement
